@@ -3,24 +3,22 @@ package SQL::Tokenizer;
 use warnings;
 use strict;
 
-use 5.006002;
-
 use Exporter;
 
 our @ISA = qw(Exporter);
 
-our @EXPORT_OK= qw(tokenize_sql);
+our @EXPORT_OK = qw(tokenize_sql);
 
-our $VERSION= '0.24';
+our $VERSION = '0.25';
 
-my $re= qr{
+my $re = qr{
     (
         (?:--|\#)[\ \t\S]*      # single line comments
         |
         (?:<>|<=>|>=|<=|==|=|!=|!|<<|>>|<|>|\|\||\||&&|&|-|\+|\*(?!/)|/(?!\*)|\%|~|\^|\?)
                                 # operators and tests
         |
-        [\[\]\(\),;.]            # punctuation (parenthesis, comma)
+        [\[\]\(\),;.]           # punctuation (parenthesis, comma)
         |
         \'\'(?!\')              # empty single quoted string
         |
@@ -32,10 +30,10 @@ my $re= qr{
         `(?>(?:(?>[^`\\]+)|``|\\.)*)+`
                                 # anything inside backticks quotes, ungreedy
         |
-        '(?>(?:(?>[^'\\]+)|''|\\.)*)+'
+        [xX]?'(?:[^'\\]++|''|\\.)*+' #posessiveness syntactic sugar for (?>pat)
                                 # anything inside single quotes, ungreedy.
         |
-        /\*[\ \t\r\n\S]*?\*/      # C style comments
+        /\*[\ \t\r\n\S]*?\*/    # C style comments
         |
         (?:[\w:@]+(?:\.(?:\w+|\*)?)*)
                                 # words, standard named placeholders, db.table.*, db.*
@@ -47,22 +45,23 @@ my $re= qr{
         |
         [\t\ ]+                 # any kind of white spaces
     )
-}smx;
+}sx; # use m too if you use ^$ in re
 
 sub tokenize_sql {
-    my ( $query, $remove_white_tokens )= @_;
+    my ($query, $remove_white_tokens) = @_;
 
-    my @query= $query =~ m{$re}smxg;
+    my @query = $query =~ m{$re}sxg; # i think only g is sufficient
 
     if ($remove_white_tokens) {
-        @query= grep( !/^[\s\n\r]*$/, @query );
+        @query = grep { !/^[\s\n\r]*$/ } @query;
     }
 
     return wantarray ? @query : \@query;
 }
 
 sub tokenize {
-    my $class= shift;
+    my $class = shift;
+
     return tokenize_sql(@_);
 }
 
@@ -82,8 +81,8 @@ SQL::Tokenizer - A simple SQL tokenizer.
 
  use SQL::Tokenizer qw(tokenize_sql);
 
- my $query= q{SELECT 1 + 1};
- my @tokens= SQL::Tokenizer->tokenize($query);
+ my $query = q{SELECT 1 + 1};
+ my @tokens = SQL::Tokenizer->tokenize($query);
 
  # @tokens now contains ('SELECT', ' ', '1', ' ', '+', ' ', '1')
 
@@ -115,10 +114,10 @@ like the one below should not be a problem:
 
  use SQL::Tokenizer qw(tokenize_sql);
 
- my @tokens= tokenize_sql($query);
- my $tokens= tokenize_sql($query);
+ my @tokens = tokenize_sql($query);
+ my $tokens = tokenize_sql($query);
 
- $tokens= tokenize_sql( $query, $remove_white_tokens );
+ $tokens = tokenize_sql( $query, $remove_white_tokens );
 
 C<tokenize_sql> can be imported to current namespace on request. It receives a
 SQL query, and returns an array of tokens if called in list context, or an
@@ -126,8 +125,8 @@ arrayref if called in scalar context.
 
 =item tokenize
 
- my @tokens= SQL::Tokenizer->tokenize($query);
- my $tokens= SQL::Tokenizer->tokenize($query);
+ my @tokens = SQL::Tokenizer->tokenize($query);
+ my $tokens = SQL::Tokenizer->tokenize($query);
 
  $tokens= SQL::Tokenizer->tokenize( $query, $remove_white_tokens );
 
@@ -183,4 +182,3 @@ This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
-
